# Welcome to Quantify's documentation!

```{include} ../README.md
```

```{toctree}
:caption: Contents
:glob: true
:maxdepth: 2

installation
usage
tutorials/index
contributing
authors
changelog
```

```{toctree}
:caption: Technical notes
:maxdepth: 2

technical_notes/dataset_design/index
```

```{toctree}
:caption: API reference
:maxdepth: 2

api_reference
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
